﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CampusTableAdapters;

/// <summary>
/// ConsultesBLL és la capa de negoci que connecta la capa de presentació amb el DataTable Consultes 
/// de la capa d’accés a dades (DAL) anomenada Campus.
/// </summary>
/// 

[System.ComponentModel.DataObject]
public class ConsultesBLL
{

    //Preparem l'accés a Consultes.
    private ConsultesTableAdapter _productsAdapter = null;
    protected ConsultesTableAdapter Adapter
    {
        get
        {
            if (_productsAdapter == null)
                _productsAdapter = new ConsultesTableAdapter();

            return _productsAdapter;
        }
    }


    //Preparem l'accés a Usuaris.
    private aspnet_UsersTableAdapter _productsAdapter2 = null;
    protected aspnet_UsersTableAdapter Adapter2
    {
        get
        {
            if (_productsAdapter2 == null)
                _productsAdapter2 = new aspnet_UsersTableAdapter();

            return _productsAdapter2;
        }
    }



    //Accés a les consultes.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, true)]
    public Campus.ConsultesDataTable GetConsultes()
    {
        return Adapter.GetConsultes();
    }



    //Accés a una consulta del curs segons el codi de la consulta.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.ConsultesDataTable GetConsultaByCodiConsulta(int codi_consulta)
    {
        return Adapter.GetConsultaByCodiConsulta(codi_consulta);
    }



    //Accés a les consultes d'un alumne.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.ConsultesDataTable GetConsultaByNomUsuari(string nom_alumne)
    {
        return Adapter.GetConsultaByNomUsuari(nom_alumne);

    }


    //Accés a les consultes d'un curs.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.ConsultesDataTable GetConsultesByCodiCurs(int codi_curs)
    {
        return Adapter.GetConsultesByCodiCurs(codi_curs);

    }



    //Accés a les consultes d'un alumne en un curs.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.ConsultesDataTable GetConsultesByCodiCursANDNomUsuari(int codi_curs, string nom_alumne)
    {
        
        // Si els usuaris no han fet cap consulta, se'afegeix un nou registre buit per visualitzar el DeatilsView1.
        Campus.ConsultesDataTable consultes1 = Adapter.GetConsultesByCodiCursANDNomUsuari(codi_curs, nom_alumne);
        if (consultes1.Count == 0)
        {
            Campus.ConsultesDataTable consultes2 = new Campus.ConsultesDataTable();
            Campus.ConsultesRow consulta = consultes2.NewConsultesRow();

            consulta.codi_consulta = 0;
            consulta.codi_curs = codi_curs;
            consulta.nom_alumne = nom_alumne;
        
            //Afegim la consulta buida.
            consultes2.AddConsultesRow(consulta);
            int rowsAffected = Adapter.Update(consultes2);        
        
        }        

        return Adapter.GetConsultesByCodiCursANDNomUsuari(codi_curs, nom_alumne);

    }



    //Inserció d'una consulta.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Insert, true)]
    public bool InsertConsulta( int codi_consulta, int codi_curs, string nom_alumne,
    string assumpte, string detall, string resposta, string fitxer_consulta, string fitxer_resposta)
    {

        //Si no existeix cap usuari amb aquest nom, no es permet afegir cap consulta.
        Campus.aspnet_UsersDataTable usuaris = Adapter2.GetUsuarisByUserName(nom_alumne);
        if (usuaris.Count == 0) return false;

        Campus.ConsultesDataTable files = Adapter.GetConsultes();

        Campus.ConsultesDataTable files2 = GetConsultesByCodiCursANDNomUsuari(codi_curs, nom_alumne);

        // Es crea una instància nova anomenada 'consultes'. 
        Campus.ConsultesDataTable consultes = new Campus.ConsultesDataTable();
        // Es crea una fila nova de la instància 'consultes'. 
        Campus.ConsultesRow consulta = consultes.NewConsultesRow();

        //Si només existeix una consulta i aquesta és la consulta buida inicial, s'esborra.
        if (files2.Count == 1) DeleteConsulta(0);

        //S'actualitzen les dades de la fila 'consulta'.
        consulta.codi_consulta = files.Count + 1;
        consulta.codi_curs = codi_curs;
        consulta.nom_alumne = nom_alumne;
           
        if (assumpte == null) consulta.SetassumpteNull();
        else consulta.assumpte = assumpte;
        if (detall == null) consulta.SetdetallNull();
        else consulta.detall = detall;
        if (resposta == null) consulta.SetrespostaNull();
        else consulta.resposta = resposta;
        if (fitxer_consulta == null) consulta.Setfitxer_consultaNull();
        else consulta.fitxer_consulta = fitxer_consulta;
        if (fitxer_resposta == null) consulta.Setfitxer_respostaNull();
        else consulta.fitxer_resposta = fitxer_resposta;


        //S'afegeix la fila 'consulta' a la instància 'consultes'. 
        consultes.AddConsultesRow(consulta);
        int rowsAffected = Adapter.Update(consultes);

        // Retorna 'cert' si la consulta s'ha afegit i 'fals' en cas contrari.
        return rowsAffected == 1;
       
    }




    //Actualització d'una consulta.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Update, true)]
    public bool UpdateConsulta(int codi_consulta, int codi_curs, string nom_alumne,
    string assumpte, string detall, string resposta, string fitxer_consulta, string fitxer_resposta)
    {
        //Si no existeix cap consulta amb aquest 'codi', no s'actualitza cap consulta.
        Campus.ConsultesDataTable consultes = Adapter.GetConsultaByCodiConsulta(codi_consulta);
        if (consultes.Count == 0) return false;

        //Si existeix la consulta es llegeix i s'actualitza amb les noves dades.
        Campus.ConsultesRow consulta = consultes[0];

 
        if (assumpte != null) consulta.assumpte = assumpte;
        if (detall != null) consulta.detall = detall;
        if (resposta != null) consulta.resposta = resposta;
        if (fitxer_consulta != null) consulta.fitxer_consulta = fitxer_consulta;
        if (fitxer_resposta != null) consulta.fitxer_resposta = fitxer_resposta;

        //S'actualitza la nova consulta.
        int rowsAffected = Adapter.Update(consulta);

        //Retorna 'cert' si la consulta s'ha actualitzat i 'fals' en cas contrari.
        return rowsAffected == 1;
    }



    //Esborrament d'una consulta.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Delete, true)]
    public bool DeleteConsulta(int codi_consulta)
    {
        int rowsAffected = Adapter.DeleteConsulta(codi_consulta);

        //Retorna 'cert' si la consulta s'ha esborrat i 'fals' en cas contrari.
        return rowsAffected == 1;
    }




}