﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CampusTableAdapters;

/// <summary>
/// InscripcionsBLL és la capa de negoci que connecta la capa de presentació amb el DataTable Inscripcions 
/// de la capa d’accés a dades (DAL) anomenada Campus.
/// </summary>
/// 

[System.ComponentModel.DataObject]
public class InscripcionsBLL
{

    //Preparem l'accés a Inscripcions.
    private InscripcionsTableAdapter _productsAdapter = null;
    protected InscripcionsTableAdapter Adapter
    {
        get
        {
            if (_productsAdapter == null)
                _productsAdapter = new InscripcionsTableAdapter();

            return _productsAdapter;
        }
    }



    //Preparem l'accés als Usuaris.
    private aspnet_UsersTableAdapter _productsAdapter2 = null;
    protected aspnet_UsersTableAdapter Adapter2
    {
        get
        {
            if (_productsAdapter2 == null)
                _productsAdapter2 = new aspnet_UsersTableAdapter();

            return _productsAdapter2;
        }
    }



    //Preparem l'accés a Curs.
    private CursTableAdapter _productsAdapter3 = null;
    protected CursTableAdapter Adapter3
    {
        get
        {
            if (_productsAdapter3 == null)
                _productsAdapter3 = new CursTableAdapter();

            return _productsAdapter3;
        }
    }





    //Accés als cursos.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, true)]
    public Campus.InscripcionsDataTable GetInscripcions()
    {
        return Adapter.GetInscripcions();
    }




    //Accés a les inscripcions d'un curs.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.InscripcionsDataTable GetInscripcionsByCodiCurs(int codi_curs)
    {
        return Adapter.GetInscripcionsByCodiCurs(codi_curs);
    }




    //Accés a les inscripcions d'un curs en un període de matriculació.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.InscripcionsDataTable GetInscripcionsByCodiCursANDPeriodeMatriculat(int codi_curs, string periode_matriculat)
    {
        return Adapter.GetInscripcionsByCodiCursANDPeriodeMatriculat(codi_curs, periode_matriculat);
    }


    

    //Inscripció d'un alumne en un curs.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Insert, true)]
    public bool InsertInscripcio(int codi_curs, string nom_alumne, string periode_matriculat)
    {
        //Si no existeix cap usuari amb aquest nom, retorna fals.
        Campus.aspnet_UsersDataTable usuaris = Adapter2.GetUsuarisByUserName(nom_alumne);
        if (usuaris.Count == 0) return false;


        //Si no existeix cap usuari amb aquest nom, retorna fals.
        Campus.CursDataTable curs = Adapter3.GetCursByCodiCurs(codi_curs);
        if (curs.Count == 0) return false;

        //Només es permeten els períodes indicats.
        if (periode_matriculat != "2011-1" && periode_matriculat != "2011-2" && periode_matriculat != "2012-1" && periode_matriculat != "2012-2") return false;


        Campus.InscripcionsDataTable inscripcions = new Campus.InscripcionsDataTable();
        Campus.InscripcionsRow inscripcio = inscripcions.NewInscripcionsRow();

        //Si la inscripció ja existeix retorna fals.
        Campus.InscripcionsDataTable inscripcions2 = Adapter.GetInscripcioByCodiCursANDNomAlumneANDPeriodeMatriculat(codi_curs, nom_alumne, periode_matriculat);
        if (inscripcions2.Count == 1)
            return false;

        //Assignem els atributs.
        inscripcio.codi_curs = codi_curs;
        inscripcio.nom_alumne = nom_alumne;
        inscripcio.periode_matriculat = periode_matriculat;


        //Afegim la nova inscripció.
        inscripcions.AddInscripcionsRow(inscripcio);
        int rowsAffected = Adapter.Update(inscripcions);

        //Retorna cert si el registre s'inserta
        //o fals en cas contrari.
        return rowsAffected == 1;
    }




    //Actualització d'inscripcions.
    [System.ComponentModel.DataObjectMethodAttribute
     (System.ComponentModel.DataObjectMethodType.Update, true)]
    public bool UpdateInscripcio(int codi_curs, string nom_alumne, string periode_matriculat)
    {
        //Si no existeix cap usuari amb aquest nom, retorna fals.
        Campus.aspnet_UsersDataTable usuaris = Adapter2.GetUsuarisByUserName(nom_alumne);
        if (usuaris.Count == 0) return false;

        //Si la inscripció ja existeix retorna fals.
        Campus.InscripcionsDataTable inscripcions = Adapter.GetInscripcioByCodiCursANDNomAlumneANDPeriodeMatriculat(codi_curs, nom_alumne, periode_matriculat);
        if (inscripcions.Count == 0)
             return false;

        Campus.InscripcionsRow inscripcio = inscripcions[0];


        //S'actualitza la inscripció.
        if (codi_curs != null) inscripcio.codi_curs = codi_curs;
        if (nom_alumne != null) inscripcio.nom_alumne = nom_alumne;
        if (periode_matriculat != null) inscripcio.periode_matriculat = periode_matriculat;
 
        inscripcio.codi_curs = codi_curs;
        inscripcio.nom_alumne = nom_alumne;
        inscripcio.periode_matriculat = periode_matriculat;




        //Actualització de la inscripció.
        int rowsAffected = Adapter.Update(inscripcio);

        //Retorna cert si el registre s'actualitza
        //o fals en cas contrari.
        return rowsAffected == 1;
    }




    //Esborrament d'una inscripció.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Delete, true)]
    public bool DeleteInscripcio(int codi_curs, string nom_alumne, string periode_matriculat)
    {
        int rowsAffected = Adapter.DeleteInscripcio(codi_curs, nom_alumne, periode_matriculat);

        //Retorna cert si el registre s'esborra
        //o fals en cas contrari.
        return rowsAffected == 1;
    }


}