﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CampusTableAdapters;

/// <summary>
/// MaterialsBLL és la capa de negoci que connecta la capa de presentació amb el DataTable Materials 
/// de la capa d’accés a dades (DAL) anomenada Campus.
/// </summary>


[System.ComponentModel.DataObject]
public class MaterialsBLL
{

    //Preparem l'accés a Materials.
    private MaterialsTableAdapter _productsAdapter = null;
    protected MaterialsTableAdapter Adapter
    {
        get {
            if (_productsAdapter == null)
                _productsAdapter = new MaterialsTableAdapter();

            return _productsAdapter;
        }
    }


    //Accés als materials.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, true)]
    public Campus.MaterialsDataTable GetMaterials()
    {
        return Adapter.GetMaterials();
    }


    //Accés als materials del curs segons els tipus.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.MaterialsDataTable GetMaterialsByCursANDTipus(string tipus, int codi_curs)
    {
        return Adapter.GetMaterialsByCursANDTipus(tipus, codi_curs);   
    }



    //Accés als materials del curs segons el codi del material.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.MaterialsDataTable GetMaterialsByCodiMaterialANDCodiCurs(int codi_material, int codi_curs)
    {
        return Adapter.GetMaterialsByCodiMaterialsANDCodiCurs(codi_material, codi_curs);
    }


    
    //Inserció de materials.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Insert, true)]
    public bool InsertMaterials(int codi_material, int codi_curs, string nom,
    string descripcio, string tipus, string contingut)
    {   
        
        Campus.MaterialsDataTable materials = new Campus.MaterialsDataTable();
        Campus.MaterialsRow material = materials.NewMaterialsRow();
    
        //Assignem un codi de material adient.
        Campus.MaterialsDataTable files = Adapter.GetMaterials();
        int b=1;
        //int a = files.Count;
        int a=0;
 
        while (b != 0)
        { 
            a = a + 1;
            Campus.MaterialsDataTable materials2 = Adapter.GetMaterialsByCodiMaterials(a);
            b = materials2.Count;           

        }

        material.codi_material = a;

        //Assignem la resta d'atributs.
        material.codi_curs = codi_curs;
        if (nom == null) material.SetnomNull();
        else material.nom = nom;
        if (descripcio == null) material.SetdescripcioNull();
        else material.descripcio = descripcio;
        if (tipus == null) material.SettipusNull();
        else material.tipus = tipus;
        if (contingut == null) material.SetcontingutNull();
        else material.contingut = contingut;
        

        //Afegim el nou material.
        materials.AddMaterialsRow(material);
        int rowsAffected = Adapter.Update(materials);

        //Retorna cert si el registre s'inserta
        //o fals en cas contrari.
        return rowsAffected == 1;
    }


    //Actualització de materials.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Update, true)]
    public bool UpdateMaterials(int codi_material, int codi_curs, string nom,
    string descripcio, string tipus, string contingut)
    {
        //Si el material no existeix retorna fals.
        Campus.MaterialsDataTable materials = Adapter.GetMaterialsByCodiMaterialsANDCodiCurs(codi_material, codi_curs);
        if (materials.Count == 0)
        return false;


        Campus.MaterialsRow material = materials[0];

        if (nom != null) material.nom = nom;
        if (descripcio != null)  material.descripcio = descripcio;
        if (tipus != null)  material.tipus = tipus;
        if (contingut != null)  material.contingut = contingut;

        //Actualització del material.
        int rowsAffected = Adapter.Update(material);

        //Retorna cert si el registre s'actualitza
        //o fals en cas contrari.
        return rowsAffected == 1;
    }


    //Esborrament de materials.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Delete, true)]
    public bool DeleteMaterials(int codi_material, int codi_curs)
    {
        int rowsAffected = Adapter.DeleteMaterials(codi_material, codi_curs);

        //Retorna cert si el registre s'esborra
        //o fals en cas contrari.
        return rowsAffected == 1;
    }

}

