﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CampusTableAdapters;

/// <summary>
/// TestsAlumnesBLL és la capa de negoci que connecta la capa de presentació amb el DataTable TestsAlumnes 
/// de la capa d’accés a dades (DAL) anomenada Campus.
/// </summary>

[System.ComponentModel.DataObject]
public class TestsAlumnesBLL
{

    //Preparem l'accés a TestsAlumnes.
    private TestsAlumnesTableAdapter _productsAdapter = null;
    protected TestsAlumnesTableAdapter Adapter
    {
        get
        {
            if (_productsAdapter == null)
                _productsAdapter = new TestsAlumnesTableAdapter();

            return _productsAdapter;
        }
    }


    //Preparem l'accés a Usuaris.
    private aspnet_UsersTableAdapter _productsAdapter2 = null;
    protected aspnet_UsersTableAdapter Adapter2
    {
        get
        {
            if (_productsAdapter2 == null)
                _productsAdapter2 = new aspnet_UsersTableAdapter();

            return _productsAdapter2;
        }
    }


    //Preparem l'accés a Inscripcions.
    private InscripcionsTableAdapter _productsAdapter3 = null;
    protected InscripcionsTableAdapter Adapter3
    {
        get
        {
            if (_productsAdapter3 == null)
                _productsAdapter3 = new InscripcionsTableAdapter();

            return _productsAdapter3;
        }
    }



    //Accés als tests dels alumnes.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, true)]
    public Campus.TestsAlumnesDataTable GetTestsAlumnes()
    {
        return Adapter.GetTestsAlumnes();
    }




    //Accés als tests dels alumnes segons el codi del test i el nom de l'alumne.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.TestsAlumnesDataTable GetTestByCodiTestsANDNomAlumne(int codi_test, string nom_alumne)
    {

        return Adapter.GetTestByCodiTestsANDNomAlumne(codi_test, nom_alumne);
   
    }




    //Accés als tests dels alumnes segons el codi del curs i el codi del test.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.TestsAlumnesDataTable GetTestsByCodiCursANDCodiTest(int codi_curs, int codi_test)
    {
        return Adapter.GetTestsByCodiCursANDCodiTest(codi_curs, codi_test);

    }




    //Accés als tests dels alumnes segons el codi del curs i el nom de l'alumne.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.TestsAlumnesDataTable GetTestsByCodiCursANDNomAlumne(int codi_curs, string nom_alumne)
    {
        return Adapter.GetTestsByCodiCursANDNomAlumne(codi_curs, nom_alumne);

    }


    

    //Inserció d'un test d'alumne.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Insert, true)]
    public bool InsertTestsAlumnes(int codi_test, string nom_alumne, string nom_test, string descripcio, int codi_curs, 
        string fitxer_lliurat, int qualificacio, string comentari)
    {

         //Si no existeix cap usuari amb aquest nom, retorna fals.
          Campus.aspnet_UsersDataTable usuaris = Adapter2.GetUsuarisByUserName(nom_alumne);
          if (usuaris.Count == 0) return false;


          //Si el test ja existeix retorna fals.
          Campus.TestsAlumnesDataTable tests1 = Adapter.GetTestByCodiTestsANDNomAlumne(codi_test, nom_alumne);
          if (tests1.Count == 1) return false;

    
          Campus.InscripcionsDataTable inscrit = Adapter3.GetInscripcionsByCodiCurs(codi_curs);
          if (inscrit.Count == 1) return false;


        // Es crea una instància nova anomenada 'consultes'. 
        Campus.TestsAlumnesDataTable tests = new Campus.TestsAlumnesDataTable();
        // Es crea una fila nova de la instància 'consultes'. 
        Campus.TestsAlumnesRow test = tests.NewTestsAlumnesRow();


        //Assignem els atributs.
        test.codi_test = codi_test;
        test.nom_alumne = nom_alumne;
        test.nom_test = nom_test;      
        test.codi_curs = codi_curs;
        test.descripcio = descripcio;
  
        if (fitxer_lliurat == null) test.Setfitxer_lliuratNull();
        else test.fitxer_lliurat = fitxer_lliurat;       
        if (comentari == null) test.SetcomentariNull();
        else test.comentari = comentari;
        if (qualificacio == null) test.SetqualificacioNull();
        else test.qualificacio = qualificacio; test.SetqualificacioNull();


        //Afegim el nou test d'alumne.
        tests.AddTestsAlumnesRow(test);
        int rowsAffected = Adapter.Update(tests);

        // Retorna 'cert' si el test d'alumne s'ha afegit i 'fals' en cas contrari.
        return rowsAffected == 1;

    }


    
    //Actualització del test d'una alumne.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Update, true)]
    public bool UpdateTestAlumne(int codi_test, string nom_alumne, string nom_test, string descripcio, int codi_curs,
        string fitxer_lliurat, int qualificacio, string comentari)
    {
        //Si no existeix el test retorna fals.
        Campus.TestsAlumnesDataTable tests = Adapter.GetTestByCodiTestsANDNomAlumne(codi_test, nom_alumne);
        if (tests.Count == 0) return false;

        Campus.TestsAlumnesRow test = tests[0];

        //S'actualitzen dades.
        if (test.Isfitxer_lliuratNull())
        {
            // Si no s'ha lliurat el test, es permet el seu lliurament.
            if (fitxer_lliurat != null) test.fitxer_lliurat = fitxer_lliurat;

        }
        else
        {
            //Si s'ha lliurat el test, s'avalua.
            if (!qualificacio.Equals(null)) test.qualificacio = qualificacio;
            if (comentari != null) test.comentari = comentari;


        }

       
        //S'actualitza.
        int rowsAffected = Adapter.Update(test);

        //Retorna 'cert' si s'ha actualitzat i 'fals' en cas contrari.
        return rowsAffected == 1;
    }

    


    //Esborrament d'un test d'alumne.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Delete, true)]
    public bool DeleteTestsAlumnes(int codi_test, string nom_alumne)
    {
        int rowsAffected = Adapter.DeleteTestsAlumnes(codi_test, nom_alumne);

        //Retorna 'cert' si s'ha esborrat i 'fals' en cas contrari.
        return rowsAffected == 1;
    }



}