﻿using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CampusTableAdapters;

/// <summary>
/// TestsBLL és la capa de negoci que connecta la capa de presentació amb el DataTable Tests 
/// de la capa d’accés a dades (DAL) anomenada Campus.
/// </summary>
/// 

[System.ComponentModel.DataObject]
public class TestsBLL
{

    //Preparem l'accés als Tests.
    private TestsTableAdapter _productsAdapter = null;
    protected TestsTableAdapter Adapter
    {
        get
        {
            if (_productsAdapter == null)
                _productsAdapter = new TestsTableAdapter();

            return _productsAdapter;
        }
    }


    //Preparem l'accés als usuaris.
    private aspnet_UsersTableAdapter _productsAdapter2 = null;
    protected aspnet_UsersTableAdapter Adapter2
    {
        get
        {
            if (_productsAdapter2 == null)
                _productsAdapter2 = new aspnet_UsersTableAdapter();

            return _productsAdapter2;
        }
    }




    //Accés als tests.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, true)]
    public Campus.TestsDataTable GetTests()
    {
        return Adapter.GetTests();
    }




    //Accés als tests d'un curs.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.TestsDataTable GetTestsByCodiCurs(int codi_curs)
    {

        // Si el test no exiteix, s'afegeix un nou registre buit per visualitzar el DeatilsView1.
        Campus.TestsDataTable tests1 = Adapter.GetTestsByCodiCurs(codi_curs);
        if (tests1.Count == 0)
        {
            Campus.TestsDataTable tests2 = new Campus.TestsDataTable();
            Campus.TestsRow test = tests2.NewTestsRow();

            test.codi_test = 0;
            test.codi_curs = codi_curs;
 
            // Afegim un test buit.
            tests2.AddTestsRow(test);
            int rowsAffected = Adapter.Update(tests2);

        }


        return Adapter.GetTestsByCodiCurs(codi_curs);
    }




    //Accés als tests segons el codi del curs i el codi del test.
    [System.ComponentModel.DataObjectMethodAttribute
        (System.ComponentModel.DataObjectMethodType.Select, false)]
    public Campus.TestsDataTable GetTestsByCodiTest(int codi_curs, int codi_test)
    {
        
        // Si el test no existeix s'afegeix un nou registre buit per visualitzar el DeatilsView1.
        Campus.TestsDataTable tets1 = Adapter.GetTestsByCodiTest(codi_test);
        if (tets1.Count == 0)
        {
            Campus.TestsDataTable tests2 = new Campus.TestsDataTable();
            Campus.TestsRow test = tests2.NewTestsRow();

            test.codi_test = 0;
            test.codi_curs = codi_curs;

            // Afegim la consulta buida
            tests2.AddTestsRow(test);
            int rowsAffected = Adapter.Update(tests2);

        }

        return Adapter.GetTestsByCodiTest(codi_test);

    }



    //Inserció d'un test.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Insert, true)]
    public bool InsertTest(int codi_curs, int codi_test, string nom_test, string descripcio, string fitxer_test)
    {

        Campus.TestsDataTable files2 = GetTestsByCodiCurs(codi_curs);

        // Es crea una instància nova anomenada 'tests'. 
        Campus.TestsDataTable tests = new Campus.TestsDataTable();
        // Es crea una fila nova de la instància 'tests'. 
        Campus.TestsRow test = tests.NewTestsRow();

        //Si només existeix un test i aquest és el test buit inicial, s'esborra.
        if (files2.Count == 1) DeleteTest(codi_curs,0);

        //S'afegeixen els atributs dels test.
        test.codi_curs = codi_curs;

        //S'assigna el codi adient al test.
        int a=0;
        int b=1;
        while (b!=0)
        {
	        a=a+1;
	        Campus.TestsDataTable tests5= Adapter.GetTestsByCodiTest(a);
	        b=tests5.Count;
        }
        test.codi_test = a;


        //S'assignen els altres atributs.
        if (nom_test == null) test.Setnom_testNull();
        else test.nom_test = nom_test;
        if (descripcio == null) test.SetdescripcioNull();
        else test.descripcio = descripcio;
        if (fitxer_test == null) test.Setfitxer_testNull();
        else test.fitxer_test = fitxer_test;

        //S'afegeix el test. 
        tests.AddTestsRow(test);
        int rowsAffected = Adapter.Update(tests);

        // Retorna 'cert' si la consulta s'ha afegit i 'fals' en cas contrari.
        return rowsAffected == 1;

    }




    //Actualització d'un test.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Update, true)]
    public bool UpdateTest(int codi_curs, int codi_test, string nom_test, string descripcio, string fitxer_test)
    {
        //Si no existeix cap test amb aquest codi retorna fals.
        Campus.TestsDataTable tests = Adapter.GetTestsByCodiTest(codi_test);
        if (tests.Count == 0) return false;
                
        Campus.TestsRow test = tests[0];

        //S'actualitzen dades.
        if (nom_test != null) test.nom_test = nom_test;
        if (descripcio != null) test.descripcio = descripcio;
        if (fitxer_test != null) test.fitxer_test = fitxer_test;
     
        
        //S'actualitza el test.
        int rowsAffected = Adapter.Update(test);

        //Retorna 'cert' si s'ha actualitzat i 'fals' en cas contrari.
        return rowsAffected == 1;
    }




    //Esborrament d'un test.
    [System.ComponentModel.DataObjectMethodAttribute
    (System.ComponentModel.DataObjectMethodType.Delete, true)]
    public bool DeleteTest(int codi_curs, int codi_test)
    {
        int rowsAffected = Adapter.DeleteTest(codi_test);

        //Retorna 'cert' si la consulta s'ha esborrat i 'fals' en cas contrari.
        return rowsAffected == 1;
    }




}